#!/bin/sh
CONTAINER_NAME=$(
    docker container run \
        -d \
        -e POSTGRES_HOST_AUTH_METHOD=trust \
        postgres:15beta1
)

echo "Waiting for database to start up"
sleep 1

run_query() {
    echo ""
    echo "$1"
    echo ""
    docker container exec -it $CONTAINER_NAME psql -h localhost -U postgres -c "$2"
}

run_query "Creating dummy data" '
create table numbers(n int);
insert into numbers (n) select generate_series(1, 1000000);
create index numbers_n_idx on numbers(n);
'

run_query 'Indexed Query: in (q)' '
explain analyze select numbers.n from (values (5000000)) quantities(q) join numbers on numbers.n in (q);
'

run_query 'Indexed Query: = (select q)' '
explain analyze select numbers.n from (values (5000000)) quantities(q) join numbers on numbers.n = (select q);
'

run_query 'Sequential Query: = any(select q)' '
explain analyze select numbers.n from (values (5000000)) quantities(q) join numbers on numbers.n = any(select q);
'

run_query 'Sequential Query: in (select q)' '
explain analyze select numbers.n from (values (5000000)) quantities(q) join numbers on numbers.n in (select q);
'

run_query 'Case Study' '
explain analyze with quantities(q) as (
	select array[10000000, 1000000, 100000, 10000, 1000, 100, 10, 1]::int[]
)
select numbers.n from quantities join numbers on numbers.n in (select unnest(quantities.q));
'

docker container stop $CONTAINER_NAME
docker container rm $CONTAINER_NAME
